==> brmo-stufbg204-1.5.2-sources.jar: nl/egem/stuf/sector/bg/_0204/VBOKennisgeving.java <==

package nl.egem.stuf.sector.bg._0204;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElementRef;
import javax.xml.bind.annotation.XmlType;


/**
 * verblijfsobject binnen kennisgeving
 * 
 * <p>Java class for VBO-kennisgeving complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="VBO-kennisgeving">
 *   &lt;complexContent>
 *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}VBO-fund">
 *       &lt;sequence>
 *         &lt;element name="VBOADR" type="{http://www.egem.nl/StUF/sector/bg/0204}ADR-relKerngegevens" minOccurs="0"/>
 *         &lt;element name="VBOBSG" maxOccurs="unbounded" minOccurs="0">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie">
 *                 &lt;sequence>
 *                   &lt;element name="BSG" type="{http://www.egem.nl/StUF/sector/bg/0204}BSG-kerngegevens"/>
 *                 &lt;/sequence>
 *               &lt;/extension>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *         &lt;element name="VBOKDO" maxOccurs="unbounded" minOccurs="0">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie">
 *                 &lt;sequence>
 *                   &lt;element name="KDO" type="{http://www.egem.nl/StUF/sector/bg/0204}KDO-kerngegevens"/>
 *                 &lt;/sequence>
 *               &lt;/extension>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *         &lt;element name="VBOSUBGBR" minOccurs="0">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie">
 *                 &lt;choice>
 *                   &lt;element name="NNP" type="{http://www.egem.nl/StUF/sector/bg/0204}NNP-kerngegevens"/>
 *                   &lt;element name="PRS" type="{http://www.egem.nl/StUF/sector/bg/0204}PRS-kerngegevens"/>
 *                 &lt;/choice>
 *               &lt;/extension>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *         &lt;element name="VBOVBOOSU" maxOccurs="unbounded" minOccurs="0">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}VBOVBOOSU-rel">
 *                 &lt;sequence>
 *                   &lt;element name="VBO" type="{http://www.egem.nl/StUF/sector/bg/0204}VBO-kerngegevens"/>
 *                 &lt;/sequence>
 *               &lt;/extension>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *       &lt;/sequence>
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "VBO-kennisgeving", propOrder = {
    "vboadr",
    "vbobsg",
    "vbokdo",
    "vbosubgbr",
    "vbovboosu"
})
public class VBOKennisgeving
    extends VBOFund
{

    @XmlElementRef(name = "VBOADR", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
    protected JAXBElement<ADRRelKerngegevens> vboadr;
    @XmlElement(name = "VBOBSG", nillable = true)
    protected List<VBOKennisgeving.VBOBSG> vbobsg;
    @XmlElement(name = "VBOKDO", nillable = true)
    protected List<VBOKennisgeving.VBOKDO> vbokdo;
    @XmlElementRef(name = "VBOSUBGBR", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
    protected JAXBElement<VBOKennisgeving.VBOSUBGBR> vbosubgbr;
    @XmlElement(name = "VBOVBOOSU", nillable = true)
    protected List<VBOKennisgeving.VBOVBOOSU> vbovboosu;

    /**
     * Gets the value of the vboadr property.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link ADRRelKerngegevens }{@code >}
     *     
     */
    public JAXBElement<ADRRelKerngegevens> getVBOADR() {
        return vboadr;
    }

    /**
     * Sets the value of the vboadr property.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link ADRRelKerngegevens }{@code >}
     *     
     */
    public void setVBOADR(JAXBElement<ADRRelKerngegevens> value) {
        this.vboadr = value;
    }

    /**
     * Gets the value of the vbobsg property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the vbobsg property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getVBOBSG().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link VBOKennisgeving.VBOBSG }
     * 
     * 
     */
    public List<VBOKennisgeving.VBOBSG> getVBOBSG() {
        if (vbobsg == null) {
            vbobsg = new ArrayList<VBOKennisgeving.VBOBSG>();
        }
        return this.vbobsg;
    }

    /**
     * Gets the value of the vbokdo property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the vbokdo property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getVBOKDO().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link VBOKennisgeving.VBOKDO }
     * 
     * 
     */
    public List<VBOKennisgeving.VBOKDO> getVBOKDO() {
        if (vbokdo == null) {
            vbokdo = new ArrayList<VBOKennisgeving.VBOKDO>();
        }
        return this.vbokdo;
    }

    /**
     * Gets the value of the vbosubgbr property.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link VBOKennisgeving.VBOSUBGBR }{@code >}
     *     
     */
    public JAXBElement<VBOKennisgeving.VBOSUBGBR> getVBOSUBGBR() {
        return vbosubgbr;
    }

    /**
     * Sets the value of the vbosubgbr property.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link VBOKennisgeving.VBOSUBGBR }{@code >}
     *     
     */
    public void setVBOSUBGBR(JAXBElement<VBOKennisgeving.VBOSUBGBR> value) {
        this.vbosubgbr = value;
    }

    /**
     * Gets the value of the vbovboosu property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the vbovboosu property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getVBOVBOOSU().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link VBOKennisgeving.VBOVBOOSU }
     * 
     * 
     */
    public List<VBOKennisgeving.VBOVBOOSU> getVBOVBOOSU() {
        if (vbovboosu == null) {
            vbovboosu = new ArrayList<VBOKennisgeving.VBOVBOOSU>();
        }
        return this.vbovboosu;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie">
     *       &lt;sequence>
     *         &lt;element name="BSG" type="{http://www.egem.nl/StUF/sector/bg/0204}BSG-kerngegevens"/>
     *       &lt;/sequence>
     *     &lt;/extension>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "bsg"
    })
    public static class VBOBSG
        extends Relatie
    {

        @XmlElement(name = "BSG", required = true, nillable = true)
        protected BSGKerngegevens bsg;

        /**
         * Gets the value of the bsg property.
         * 
         * @return
         *     possible object is
         *     {@link BSGKerngegevens }
         *     
         */
        public BSGKerngegevens getBSG() {
            return bsg;
        }

        /**
         * Sets the value of the bsg property.
         * 
         * @param value
         *     allowed object is
         *     {@link BSGKerngegevens }
         *     
         */
        public void setBSG(BSGKerngegevens value) {
            this.bsg = value;
        }

    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie">
     *       &lt;sequence>
     *         &lt;element name="KDO" type="{http://www.egem.nl/StUF/sector/bg/0204}KDO-kerngegevens"/>
     *       &lt;/sequence>
     *     &lt;/extension>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "kdo"
    })
    public static class VBOKDO
        extends Relatie
    {

        @XmlElement(name = "KDO", required = true, nillable = true)
        protected KDOKerngegevens kdo;

        /**
         * Gets the value of the kdo property.
         * 
         * @return
         *     possible object is
         *     {@link KDOKerngegevens }
         *     
         */
        public KDOKerngegevens getKDO() {
            return kdo;
        }

        /**
         * Sets the value of the kdo property.
         * 
         * @param value
         *     allowed object is
         *     {@link KDOKerngegevens }
         *     
         */
        public void setKDO(KDOKerngegevens value) {
            this.kdo = value;
        }

    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie">
     *       &lt;choice>
     *         &lt;element name="NNP" type="{http://www.egem.nl/StUF/sector/bg/0204}NNP-kerngegevens"/>
     *         &lt;element name="PRS" type="{http://www.egem.nl/StUF/sector/bg/0204}PRS-kerngegevens"/>
     *       &lt;/choice>
     *     &lt;/extension>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "nnp",
        "prs"
    })
    public static class VBOSUBGBR
        extends Relatie
    {

        @XmlElementRef(name = "NNP", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
        protected JAXBElement<NNPKerngegevens> nnp;
        @XmlElementRef(name = "PRS", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
        protected JAXBElement<PRSKerngegevens> prs;

        /**
         * Gets the value of the nnp property.
         * 
         * @return
         *     possible object is
         *     {@link JAXBElement }{@code <}{@link NNPKerngegevens }{@code >}
         *     
         */
        public JAXBElement<NNPKerngegevens> getNNP() {
            return nnp;
        }

        /**
         * Sets the value of the nnp property.
         * 
         * @param value
         *     allowed object is
         *     {@link JAXBElement }{@code <}{@link NNPKerngegevens }{@code >}
         *     
         */
        public void setNNP(JAXBElement<NNPKerngegevens> value) {
            this.nnp = value;
        }

        /**
         * Gets the value of the prs property.
         * 
         * @return
         *     possible object is
         *     {@link JAXBElement }{@code <}{@link PRSKerngegevens }{@code >}
         *     
         */
        public JAXBElement<PRSKerngegevens> getPRS() {
            return prs;
        }

        /**
         * Sets the value of the prs property.
         * 
         * @param value
         *     allowed object is
         *     {@link JAXBElement }{@code <}{@link PRSKerngegevens }{@code >}
         *     
         */
        public void setPRS(JAXBElement<PRSKerngegevens> value) {
            this.prs = value;
        }

    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}VBOVBOOSU-rel">
     *       &lt;sequence>
     *         &lt;element name="VBO" type="{http://www.egem.nl/StUF/sector/bg/0204}VBO-kerngegevens"/>
     *       &lt;/sequence>
     *     &lt;/extension>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "vbo"
    })
    public static class VBOVBOOSU
        extends VBOVBOOSURel
    {

        @XmlElement(name = "VBO", required = true, nillable = true)
        protected VBOKerngegevens vbo;

        /**
         * Gets the value of the vbo property.
         * 
         * @return
         *     possible object is
         *     {@link VBOKerngegevens }
         *     
         */
        public VBOKerngegevens getVBO() {
            return vbo;
        }

        /**
         * Sets the value of the vbo property.
         * 
         * @param value
         *     allowed object is
         *     {@link VBOKerngegevens }
         *     
         */
        public void setVBO(VBOKerngegevens value) {
            this.vbo = value;
        }

    }

}

==> brmo-stufbg204-2.0.1-sources.jar: nl/egem/stuf/sector/bg/_0204/VBOKennisgeving.java <==

package nl.egem.stuf.sector.bg._0204;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElementRef;
import javax.xml.bind.annotation.XmlType;


/**
 * verblijfsobject binnen kennisgeving
 * 
 * <p>Java class for VBO-kennisgeving complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="VBO-kennisgeving"&gt;
 *   &lt;complexContent&gt;
 *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}VBO-fund"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="VBOADR" type="{http://www.egem.nl/StUF/sector/bg/0204}ADR-relKerngegevens" minOccurs="0"/&gt;
 *         &lt;element name="VBOBSG" maxOccurs="unbounded" minOccurs="0"&gt;
 *           &lt;complexType&gt;
 *             &lt;complexContent&gt;
 *               &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie"&gt;
 *                 &lt;sequence&gt;
 *                   &lt;element name="BSG" type="{http://www.egem.nl/StUF/sector/bg/0204}BSG-kerngegevens"/&gt;
 *                 &lt;/sequence&gt;
 *               &lt;/extension&gt;
 *             &lt;/complexContent&gt;
 *           &lt;/complexType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="VBOKDO" maxOccurs="unbounded" minOccurs="0"&gt;
 *           &lt;complexType&gt;
 *             &lt;complexContent&gt;
 *               &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie"&gt;
 *                 &lt;sequence&gt;
 *                   &lt;element name="KDO" type="{http://www.egem.nl/StUF/sector/bg/0204}KDO-kerngegevens"/&gt;
 *                 &lt;/sequence&gt;
 *               &lt;/extension&gt;
 *             &lt;/complexContent&gt;
 *           &lt;/complexType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="VBOSUBGBR" minOccurs="0"&gt;
 *           &lt;complexType&gt;
 *             &lt;complexContent&gt;
 *               &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie"&gt;
 *                 &lt;choice&gt;
 *                   &lt;element name="NNP" type="{http://www.egem.nl/StUF/sector/bg/0204}NNP-kerngegevens"/&gt;
 *                   &lt;element name="PRS" type="{http://www.egem.nl/StUF/sector/bg/0204}PRS-kerngegevens"/&gt;
 *                 &lt;/choice&gt;
 *               &lt;/extension&gt;
 *             &lt;/complexContent&gt;
 *           &lt;/complexType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="VBOVBOOSU" maxOccurs="unbounded" minOccurs="0"&gt;
 *           &lt;complexType&gt;
 *             &lt;complexContent&gt;
 *               &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}VBOVBOOSU-rel"&gt;
 *                 &lt;sequence&gt;
 *                   &lt;element name="VBO" type="{http://www.egem.nl/StUF/sector/bg/0204}VBO-kerngegevens"/&gt;
 *                 &lt;/sequence&gt;
 *               &lt;/extension&gt;
 *             &lt;/complexContent&gt;
 *           &lt;/complexType&gt;
 *         &lt;/element&gt;
 *       &lt;/sequence&gt;
 *     &lt;/extension&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "VBO-kennisgeving", propOrder = {
    "vboadr",
    "vbobsg",
    "vbokdo",
    "vbosubgbr",
    "vbovboosu"
})
public class VBOKennisgeving
    extends VBOFund
{

    @XmlElementRef(name = "VBOADR", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
    protected JAXBElement<ADRRelKerngegevens> vboadr;
    @XmlElement(name = "VBOBSG", nillable = true)
    protected List<VBOKennisgeving.VBOBSG> vbobsg;
    @XmlElement(name = "VBOKDO", nillable = true)
    protected List<VBOKennisgeving.VBOKDO> vbokdo;
    @XmlElementRef(name = "VBOSUBGBR", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
    protected JAXBElement<VBOKennisgeving.VBOSUBGBR> vbosubgbr;
    @XmlElement(name = "VBOVBOOSU", nillable = true)
    protected List<VBOKennisgeving.VBOVBOOSU> vbovboosu;

    /**
     * Gets the value of the vboadr property.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link ADRRelKerngegevens }{@code >}
     *     
     */
    public JAXBElement<ADRRelKerngegevens> getVBOADR() {
        return vboadr;
    }

    /**
     * Sets the value of the vboadr property.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link ADRRelKerngegevens }{@code >}
     *     
     */
    public void setVBOADR(JAXBElement<ADRRelKerngegevens> value) {
        this.vboadr = value;
    }

    /**
     * Gets the value of the vbobsg property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the vbobsg property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getVBOBSG().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link VBOKennisgeving.VBOBSG }
     * 
     * 
     */
    public List<VBOKennisgeving.VBOBSG> getVBOBSG() {
        if (vbobsg == null) {
            vbobsg = new ArrayList<VBOKennisgeving.VBOBSG>();
        }
        return this.vbobsg;
    }

    /**
     * Gets the value of the vbokdo property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the vbokdo property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getVBOKDO().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link VBOKennisgeving.VBOKDO }
     * 
     * 
     */
    public List<VBOKennisgeving.VBOKDO> getVBOKDO() {
        if (vbokdo == null) {
            vbokdo = new ArrayList<VBOKennisgeving.VBOKDO>();
        }
        return this.vbokdo;
    }

    /**
     * Gets the value of the vbosubgbr property.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link VBOKennisgeving.VBOSUBGBR }{@code >}
     *     
     */
    public JAXBElement<VBOKennisgeving.VBOSUBGBR> getVBOSUBGBR() {
        return vbosubgbr;
    }

    /**
     * Sets the value of the vbosubgbr property.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link VBOKennisgeving.VBOSUBGBR }{@code >}
     *     
     */
    public void setVBOSUBGBR(JAXBElement<VBOKennisgeving.VBOSUBGBR> value) {
        this.vbosubgbr = value;
    }

    /**
     * Gets the value of the vbovboosu property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the vbovboosu property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getVBOVBOOSU().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link VBOKennisgeving.VBOVBOOSU }
     * 
     * 
     */
    public List<VBOKennisgeving.VBOVBOOSU> getVBOVBOOSU() {
        if (vbovboosu == null) {
            vbovboosu = new ArrayList<VBOKennisgeving.VBOVBOOSU>();
        }
        return this.vbovboosu;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType&gt;
     *   &lt;complexContent&gt;
     *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie"&gt;
     *       &lt;sequence&gt;
     *         &lt;element name="BSG" type="{http://www.egem.nl/StUF/sector/bg/0204}BSG-kerngegevens"/&gt;
     *       &lt;/sequence&gt;
     *     &lt;/extension&gt;
     *   &lt;/complexContent&gt;
     * &lt;/complexType&gt;
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "bsg"
    })
    public static class VBOBSG
        extends Relatie
    {

        @XmlElement(name = "BSG", required = true, nillable = true)
        protected BSGKerngegevens bsg;

        /**
         * Gets the value of the bsg property.
         * 
         * @return
         *     possible object is
         *     {@link BSGKerngegevens }
         *     
         */
        public BSGKerngegevens getBSG() {
            return bsg;
        }

        /**
         * Sets the value of the bsg property.
         * 
         * @param value
         *     allowed object is
         *     {@link BSGKerngegevens }
         *     
         */
        public void setBSG(BSGKerngegevens value) {
            this.bsg = value;
        }

    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType&gt;
     *   &lt;complexContent&gt;
     *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie"&gt;
     *       &lt;sequence&gt;
     *         &lt;element name="KDO" type="{http://www.egem.nl/StUF/sector/bg/0204}KDO-kerngegevens"/&gt;
     *       &lt;/sequence&gt;
     *     &lt;/extension&gt;
     *   &lt;/complexContent&gt;
     * &lt;/complexType&gt;
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "kdo"
    })
    public static class VBOKDO
        extends Relatie
    {

        @XmlElement(name = "KDO", required = true, nillable = true)
        protected KDOKerngegevens kdo;

        /**
         * Gets the value of the kdo property.
         * 
         * @return
         *     possible object is
         *     {@link KDOKerngegevens }
         *     
         */
        public KDOKerngegevens getKDO() {
            return kdo;
        }

        /**
         * Sets the value of the kdo property.
         * 
         * @param value
         *     allowed object is
         *     {@link KDOKerngegevens }
         *     
         */
        public void setKDO(KDOKerngegevens value) {
            this.kdo = value;
        }

    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType&gt;
     *   &lt;complexContent&gt;
     *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}Relatie"&gt;
     *       &lt;choice&gt;
     *         &lt;element name="NNP" type="{http://www.egem.nl/StUF/sector/bg/0204}NNP-kerngegevens"/&gt;
     *         &lt;element name="PRS" type="{http://www.egem.nl/StUF/sector/bg/0204}PRS-kerngegevens"/&gt;
     *       &lt;/choice&gt;
     *     &lt;/extension&gt;
     *   &lt;/complexContent&gt;
     * &lt;/complexType&gt;
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "nnp",
        "prs"
    })
    public static class VBOSUBGBR
        extends Relatie
    {

        @XmlElementRef(name = "NNP", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
        protected JAXBElement<NNPKerngegevens> nnp;
        @XmlElementRef(name = "PRS", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
        protected JAXBElement<PRSKerngegevens> prs;

        /**
         * Gets the value of the nnp property.
         * 
         * @return
         *     possible object is
         *     {@link JAXBElement }{@code <}{@link NNPKerngegevens }{@code >}
         *     
         */
        public JAXBElement<NNPKerngegevens> getNNP() {
            return nnp;
        }

        /**
         * Sets the value of the nnp property.
         * 
         * @param value
         *     allowed object is
         *     {@link JAXBElement }{@code <}{@link NNPKerngegevens }{@code >}
         *     
         */
        public void setNNP(JAXBElement<NNPKerngegevens> value) {
            this.nnp = value;
        }

        /**
         * Gets the value of the prs property.
         * 
         * @return
         *     possible object is
         *     {@link JAXBElement }{@code <}{@link PRSKerngegevens }{@code >}
         *     
         */
        public JAXBElement<PRSKerngegevens> getPRS() {
            return prs;
        }

        /**
         * Sets the value of the prs property.
         * 
         * @param value
         *     allowed object is
         *     {@link JAXBElement }{@code <}{@link PRSKerngegevens }{@code >}
         *     
         */
        public void setPRS(JAXBElement<PRSKerngegevens> value) {
            this.prs = value;
        }

    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType&gt;
     *   &lt;complexContent&gt;
     *     &lt;extension base="{http://www.egem.nl/StUF/sector/bg/0204}VBOVBOOSU-rel"&gt;
     *       &lt;sequence&gt;
     *         &lt;element name="VBO" type="{http://www.egem.nl/StUF/sector/bg/0204}VBO-kerngegevens"/&gt;
     *       &lt;/sequence&gt;
     *     &lt;/extension&gt;
     *   &lt;/complexContent&gt;
     * &lt;/complexType&gt;
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "vbo"
    })
    public static class VBOVBOOSU
        extends VBOVBOOSURel
    {

        @XmlElement(name = "VBO", required = true, nillable = true)
        protected VBOKerngegevens vbo;

        /**
         * Gets the value of the vbo property.
         * 
         * @return
         *     possible object is
         *     {@link VBOKerngegevens }
         *     
         */
        public VBOKerngegevens getVBO() {
            return vbo;
        }

        /**
         * Sets the value of the vbo property.
         * 
         * @param value
         *     allowed object is
         *     {@link VBOKerngegevens }
         *     
         */
        public void setVBO(VBOKerngegevens value) {
            this.vbo = value;
        }

    }

}
